==> haskell-yesod-core-1.6.27.1-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-core
version:              1.6.27.1
visibility:           public
id:                   yesod-core-1.6.27.1-EyZghhvLerL2tW5N4BMkCJ
key:                  yesod-core-1.6.27.1-EyZghhvLerL2tW5N4BMkCJ
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>

category:             Web, Yesod
abi:                  e7f0f043b639056cab8af6529c63e28e
exposed:              True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types

hidden-modules:
    Yesod.Core.Internal.Session Yesod.Core.Internal.Request
    Yesod.Core.Class.Handler Yesod.Core.Internal.Util
    Yesod.Core.Internal.Response Yesod.Core.Internal.Run
    Yesod.Core.Internal.TH Yesod.Core.Internal.LiteApp
    Yesod.Core.Class.Yesod Yesod.Core.Class.Dispatch
    Yesod.Core.Class.Breadcrumbs Yesod.Core.TypeCache Paths_yesod_core
    Yesod.Routes.TH Yesod.Routes.Class Yesod.Routes.Parse
    Yesod.Routes.Overlap Yesod.Routes.TH.Dispatch
    Yesod.Routes.TH.RenderRoute Yesod.Routes.TH.ParseRoute
    Yesod.Routes.TH.RouteAttrs

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-core-1.6.27.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-core-1.6.27.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-core-1.6.27.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-core
hs-libraries:         HSyesod-core-1.6.27.1-EyZghhvLerL2tW5N4BMkCJ
depends:
    aeson-2.1.2.1-HdmwuFbnNgF6PqutsUaf6Y
    attoparsec-aeson-2.1.0.0-13Pvp2p9HEQJVLcOXfIouF
    auto-update-0.1.6-BP7ZhxcIenAIOTU8CTkm3t base-4.17.2.1
    blaze-html-0.9.2.0-Af5P3A2URAm8PEOIhy6b3k
    blaze-markup-0.8.3.0-Alr6JP17MQvDFN7aUk8LfK bytestring-0.11.5.3
    case-insensitive-1.2.1.0-Abd5Q51hq5G7EsMEex29Bt
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    clientsession-0.9.3.0-HU1dV4M4ZYi5fvtSyFDY3U
    conduit-1.3.6.1-8TTHoZfFEcNByedkE9Rv7V
    conduit-extra-1.3.8-5tATRySgxkKGEeqgx2l5Qz containers-0.6.7
    cookie-0.4.6-4KcZJbma3z5GIFijXOzknm
    data-default-0.7.1.2-6Zl8APX45CF9ONl13lbZ09 deepseq-1.4.8.0
    entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    fast-logger-3.2.3-43J6juoTNIo1lHxPhVo33u
    http-types-0.12.4-ERErpW4oIqaKIzWiLMLiFN
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    monad-logger-0.3.42-ET7VjzWt2HKF3vGMDQPxAm mtl-2.2.2
    parsec-3.1.16.1 path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    primitive-0.9.0.0-BHqivtPzLOB6VfmzYm3KVP
    random-1.2.1.3-6Q31h3pRIgvDA2QDH6tJjk
    resourcet-1.2.6-EDu2BuTIWaf4YhdsfzLxLM
    shakespeare-2.1.3-C4PzgEs43SJ2cv9Csuh3LC template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    unix-compat-0.7.4-BZWTyxtN7nl3Z0fwlVJ8w5
    unliftio-0.2.25.1-CSkQ6WBjw9j80OvsxjG0yH
    unordered-containers-0.2.20-DaOkK38PYRa9pF7ZwbG4ZB
    vector-0.13.2.0-5IsJnyR8rmEEUPyguFia6U
    wai-3.2.4-4XAAckw9HTnIyst5cAezpH
    wai-extra-3.1.17-H3NdvAh2tYSGY4oK7M3yji
    wai-logger-2.5.0-8MauejjV3LZAA2jKYjAwfz
    warp-3.3.30-4IsuVtgTa031VwzjyQOJNG
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:   /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html:         /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-core-1.6.27.1-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-core
version:              1.6.27.1
visibility:           public
id:                   yesod-core-1.6.27.1-5hnBS0Z2Jx2LBqBQo2mX3X
key:                  yesod-core-1.6.27.1-5hnBS0Z2Jx2LBqBQo2mX3X
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>

category:             Web, Yesod
abi:                  d64d6a1370129abde972fc1402fd290d
exposed:              True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types

hidden-modules:
    Yesod.Core.Internal.Session Yesod.Core.Internal.Request
    Yesod.Core.Class.Handler Yesod.Core.Internal.Util
    Yesod.Core.Internal.Response Yesod.Core.Internal.Run
    Yesod.Core.Internal.TH Yesod.Core.Internal.LiteApp
    Yesod.Core.Class.Yesod Yesod.Core.Class.Dispatch
    Yesod.Core.Class.Breadcrumbs Yesod.Core.TypeCache Paths_yesod_core
    Yesod.Routes.TH Yesod.Routes.Class Yesod.Routes.Parse
    Yesod.Routes.Overlap Yesod.Routes.TH.Dispatch
    Yesod.Routes.TH.RenderRoute Yesod.Routes.TH.ParseRoute
    Yesod.Routes.TH.RouteAttrs

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-core-1.6.27.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-core-1.6.27.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-core-1.6.27.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-core
hs-libraries:         HSyesod-core-1.6.27.1-5hnBS0Z2Jx2LBqBQo2mX3X
depends:
    aeson-2.1.2.1-HdmwuFbnNgF6PqutsUaf6Y
    attoparsec-aeson-2.1.0.0-13Pvp2p9HEQJVLcOXfIouF
    auto-update-0.1.6-BP7ZhxcIenAIOTU8CTkm3t base-4.17.2.1
    blaze-html-0.9.2.0-Af5P3A2URAm8PEOIhy6b3k
    blaze-markup-0.8.3.0-Alr6JP17MQvDFN7aUk8LfK bytestring-0.11.5.3
    case-insensitive-1.2.1.0-Abd5Q51hq5G7EsMEex29Bt
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    clientsession-0.9.3.0-6fsHS1O5PSxBhiIduq2knm
    conduit-1.3.6.1-8TTHoZfFEcNByedkE9Rv7V
    conduit-extra-1.3.8-5tATRySgxkKGEeqgx2l5Qz containers-0.6.7
    cookie-0.4.6-4KcZJbma3z5GIFijXOzknm
    data-default-0.7.1.2-6Zl8APX45CF9ONl13lbZ09 deepseq-1.4.8.0
    entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    fast-logger-3.2.3-43J6juoTNIo1lHxPhVo33u
    http-types-0.12.4-ERErpW4oIqaKIzWiLMLiFN
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    monad-logger-0.3.42-ET7VjzWt2HKF3vGMDQPxAm mtl-2.2.2
    parsec-3.1.16.1 path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    primitive-0.9.0.0-BHqivtPzLOB6VfmzYm3KVP
    random-1.2.1.3-6Q31h3pRIgvDA2QDH6tJjk
    resourcet-1.2.6-EDu2BuTIWaf4YhdsfzLxLM
    shakespeare-2.1.3-C4PzgEs43SJ2cv9Csuh3LC template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    unix-compat-0.7.4-BZWTyxtN7nl3Z0fwlVJ8w5
    unliftio-0.2.25.1-CSkQ6WBjw9j80OvsxjG0yH
    unordered-containers-0.2.20-DaOkK38PYRa9pF7ZwbG4ZB
    vector-0.13.2.0-5IsJnyR8rmEEUPyguFia6U
    wai-3.2.4-4XAAckw9HTnIyst5cAezpH
    wai-extra-3.1.17-53XV29eB5n9H5kmds7FJvQ
    wai-logger-2.5.0-8MauejjV3LZAA2jKYjAwfz
    warp-3.3.30-1sM6lmV0MZX18rPjR7YNXZ
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:   /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html:         /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
